==> sparklyr_1.4.0.tar.gz: sparklyr/R/reexports.R <==
#' @include dplyr_join.R
#' @include dplyr_spark.R
#' @include dplyr_spark_table.R
#' @include sdf_interface.R
#' @include test_connection.R
#' @include tidyr_fill.R
#' @include tidyr_nest.R
#' @include tidyr_pivot_longer.R
#' @include tidyr_pivot_wider.R
#' @include tidyr_separate.R
#' @include tidyr_unite.R
#' @include tidyr_unnest.R
NULL

#' Pipe operator
#'
#' See \code{\link[dplyr:reexports]{\%>\%}} for more details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom dplyr %>%
#' @usage lhs \%>\% rhs
NULL

#' Copy To
#'
#' See \code{\link[dplyr:copy_to]{copy_to}} for more details.
#'
#' @name copy_to
#' @keywords internal
#' @export
#' @importFrom dplyr copy_to
NULL

#' Collect
#'
#' See \code{\link[dplyr:compute]{collect}} for more details.
#'
#' @name collect
#' @keywords internal
#' @export
#' @importFrom dplyr collect
NULL

#' Inner join
#'
#' See \code{\link[dplyr:mutate-joins]{inner_join}} for more details.
#'
#' @name inner_join
#' @export
#' @importFrom dplyr inner_join
NULL

#' Left join
#'
#' See \code{\link[dplyr:mutate-joins]{left_join}} for more details.
#'
#' @name left_join
#' @export
#' @importFrom dplyr left_join
NULL

#' Right join
#'
#' See \code{\link[dplyr:mutate-joins]{right_join}} for more details.
#'
#' @name right_join
#' @export
#' @importFrom dplyr right_join
NULL

#' Full join
#'
#' See \code{\link[dplyr:mutate-joins]{full_join}} for more details.
#'
#' @name full_join
#' @export
#' @importFrom dplyr full_join
NULL

#' Nest
#'
#' See \code{\link[tidyr:nest]{nest}} for more details.
#'
#' @name nest
#' @export
#' @importFrom tidyr nest
NULL

#' Unnest
#'
#' See \code{\link[tidyr:nest]{unnest}} for more details.
#'
#' @name unnest
#' @export
#' @importFrom tidyr unnest
NULL

#' Separate
#'
#' See \code{\link[tidyr:separate]{separate}} for more details.
#'
#' @name separate
#' @export
#' @importFrom tidyr separate
NULL

#' Unite
#'
#' See \code{\link[tidyr:unite]{unite}} for more details.
#'
#' @name unite
#' @export
#' @importFrom tidyr unite
NULL

#' Pivot wider
#'
#' See \code{\link[tidyr:pivot_wider]{pivot_wider}} for more details.
#'
#' @name pivot_wider
#' @export
#' @importFrom tidyr pivot_wider
NULL

#' Pivot longer
#'
#' See \code{\link[tidyr:pivot_longer]{pivot_longer}} for more details.
#'
#' @name pivot_longer
#' @export
#' @importFrom tidyr pivot_longer
NULL

#' Fill
#'
#' See \code{\link[tidyr:fill]{fill}} for more details.
#'
#' @name fill
#' @export
#' @importFrom tidyr fill
NULL

==> sparklyr_1.5.1.tar.gz: sparklyr/R/reexports.R <==
#' @include dplyr_join.R
#' @include dplyr_spark.R
#' @include dplyr_spark_table.R
#' @include dplyr_sql.R
#' @include sdf_interface.R
#' @include test_connection.R
#' @include tidyr_fill.R
#' @include tidyr_nest.R
#' @include tidyr_pivot_longer.R
#' @include tidyr_pivot_wider.R
#' @include tidyr_separate.R
#' @include tidyr_unite.R
#' @include tidyr_unnest.R
NULL

#' Pipe operator
#'
#' See \code{\link[dplyr:reexports]{\%>\%}} for more details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom dplyr %>%
NULL

#' Copy To
#'
#' See \code{\link[dplyr:copy_to]{copy_to}} for more details.
#'
#' @name copy_to
#' @keywords internal
#' @export
#' @importFrom dplyr copy_to
NULL

#' Collect
#'
#' See \code{\link[dplyr:compute]{collect}} for more details.
#'
#' @name collect
#' @keywords internal
#' @export
#' @importFrom dplyr collect
NULL

#' Inner join
#'
#' See \code{\link[dplyr:mutate-joins]{inner_join}} for more details.
#'
#' @name inner_join
#' @export
#' @importFrom dplyr inner_join
NULL

#' Left join
#'
#' See \code{\link[dplyr:mutate-joins]{left_join}} for more details.
#'
#' @name left_join
#' @export
#' @importFrom dplyr left_join
NULL

#' Right join
#'
#' See \code{\link[dplyr:mutate-joins]{right_join}} for more details.
#'
#' @name right_join
#' @export
#' @importFrom dplyr right_join
NULL

#' Full join
#'
#' See \code{\link[dplyr:mutate-joins]{full_join}} for more details.
#'
#' @name full_join
#' @export
#' @importFrom dplyr full_join
NULL

#' Nest
#'
#' See \code{\link[tidyr:nest]{nest}} for more details.
#'
#' @name nest
#' @export
#' @importFrom tidyr nest
NULL

#' Unnest
#'
#' See \code{\link[tidyr:nest]{unnest}} for more details.
#'
#' @name unnest
#' @export
#' @importFrom tidyr unnest
NULL

#' Separate
#'
#' See \code{\link[tidyr:separate]{separate}} for more details.
#'
#' @name separate
#' @export
#' @importFrom tidyr separate
NULL

#' Unite
#'
#' See \code{\link[tidyr:unite]{unite}} for more details.
#'
#' @name unite
#' @export
#' @importFrom tidyr unite
NULL

#' Pivot wider
#'
#' See \code{\link[tidyr:pivot_wider]{pivot_wider}} for more details.
#'
#' @name pivot_wider
#' @export
#' @importFrom tidyr pivot_wider
NULL

#' Pivot longer
#'
#' See \code{\link[tidyr:pivot_longer]{pivot_longer}} for more details.
#'
#' @name pivot_longer
#' @export
#' @importFrom tidyr pivot_longer
NULL

#' Fill
#'
#' See \code{\link[tidyr:fill]{fill}} for more details.
#'
#' @name fill
#' @export
#' @importFrom tidyr fill
NULL

#' Distinct
#'
#' See \code{\link[dplyr:distinct]{distinct}} for more details.
#'
#' @name distinct
#' @export
#' @importFrom dplyr distinct
NULL
